function [nodes] = basis_gen_rnd_nodes(basis_types, num_nodes)
%BASIS_GEN_RND_NODES generates random nodes distributed according to basis types.
%
%  Input:
%    basis_types - cell array of length d,
%                  contains either 'fourier' or 'chebyshev' or 'legendre'
%    num_nodes - scalar with number of nodes to return
%
%  Output:
%    nodes - random nodes distributed as requested
%
% version with generalizations 2018-2019 by Toni Volkmer

d = length(basis_types);

nodes = zeros(num_nodes, d);

for j = 1:d
  basis_type_j = basis_types{j};
  switch basis_type_j
    case 'fourier'
      nodes(:,j) = rand(num_nodes,1);
    case {'chebyshev', 'legendre_preconditioned'}
      nodes(:,j) = sin(pi*(rand(num_nodes,1)-1/2));
    case 'legendre'
      nodes(:,j) = 2*rand(num_nodes,1)-1;
    otherwise
      error('unknown basis type: %s', basis_type_j);
  end
end

end

